@@ -33,6 +33,7 @@ G_BEGIN_DECLS
 
 /* tags */
 #define GST_RIFF_TAG_RIFF GST_MAKE_FOURCC ('R','I','F','F')
+#define GST_RIFF_TAG_AVF0 GST_MAKE_FOURCC ('A','V','F','0')
 #define GST_RIFF_TAG_RIFX GST_MAKE_FOURCC ('R','I','F','X')
 #define GST_RIFF_TAG_LIST GST_MAKE_FOURCC ('L','I','S','T')
 #define GST_RIFF_TAG_avih GST_MAKE_FOURCC ('a','v','i','h')
@@ -42,6 +43,7 @@ G_BEGIN_DECLS
 #define GST_RIFF_TAG_strf GST_MAKE_FOURCC ('s','t','r','f')
 #define GST_RIFF_TAG_vedt GST_MAKE_FOURCC ('v','e','d','t')
 #define GST_RIFF_TAG_JUNK GST_MAKE_FOURCC ('J','U','N','K')
+#define GST_RIFF_TAG_JUNQ GST_MAKE_FOURCC ('J','U','N','Q')
 #define GST_RIFF_TAG_idx1 GST_MAKE_FOURCC ('i','d','x','1')
 #define GST_RIFF_TAG_dmlh GST_MAKE_FOURCC ('d','m','l','h')
 /* WAV stuff */
@@ -52,6 +54,7 @@ G_BEGIN_DECLS
 #define GST_RIFF_TAG_bext GST_MAKE_FOURCC ('b','e','x','t')
 #define GST_RIFF_TAG_BEXT GST_MAKE_FOURCC ('B','E','X','T')
 #define GST_RIFF_TAG_fact GST_MAKE_FOURCC ('f','a','c','t')
+#define GST_RIFF_TAG_acid GST_MAKE_FOURCC ('a','c','i','d')
 
 /* LIST types */
 #define GST_RIFF_LIST_movi GST_MAKE_FOURCC ('m','o','v','i')
@@ -134,6 +137,8 @@ G_BEGIN_DECLS
 #define GST_RIFF_WHAM GST_MAKE_FOURCC ('W', 'H', 'A', 'M')
 #define GST_RIFF_rgb  GST_MAKE_FOURCC (0x00,0x00,0x00,0x00)
 #define GST_RIFF_RGB  GST_MAKE_FOURCC ('R', 'G', 'B', ' ')
+#define GST_RIFF_RAW  GST_MAKE_FOURCC ('R', 'A', 'W', ' ')
+#define GST_RIFF_DIB  GST_MAKE_FOURCC ('D', 'I', 'B', ' ')
 #define GST_RIFF_rle8 GST_MAKE_FOURCC (0x01,0x00,0x00,0x00)
 #define GST_RIFF_RLE8 GST_MAKE_FOURCC ('R', 'L', 'E', '8')
 #define GST_RIFF_rle4 GST_MAKE_FOURCC (0x02,0x00,0x00,0x00)
@@ -277,23 +282,72 @@ typedef struct _gst_riff_strf_auds {       /* == WaveHeader (?) */
 #define GST_RIFF_WAVE_FORMAT_UNKNOWN        (0x0000)
 #define GST_RIFF_WAVE_FORMAT_PCM            (0x0001)
 #define GST_RIFF_WAVE_FORMAT_ADPCM          (0x0002)
+#define GST_RIFF_WAVE_FORMAT_IEEE_FLOAT     (0x0003)
+#define GST_RIFF_WAVE_FORMAT_VSELP          (0x0004)
 #define GST_RIFF_WAVE_FORMAT_IBM_CVSD       (0x0005)
 #define GST_RIFF_WAVE_FORMAT_ALAW           (0x0006)
 #define GST_RIFF_WAVE_FORMAT_MULAW          (0x0007)
 #define GST_RIFF_WAVE_FORMAT_WMS            (0x000a) /* WMS Windows Media Audio Speech */
 #define GST_RIFF_WAVE_FORMAT_OKI_ADPCM      (0x0010)
 #define GST_RIFF_WAVE_FORMAT_DVI_ADPCM      (0x0011)
+#define GST_RIFF_WAVE_FORMAT_MEDIASPACE_ADPCM (0x0012)
+#define GST_RIFF_WAVE_FORMAT_SIERRA_ADPCM   (0x0013)
+#define GST_RIFF_WAVE_FORMAT_G723_ADPCM     (0x0014)
 #define GST_RIFF_WAVE_FORMAT_DIGISTD        (0x0015)
 #define GST_RIFF_WAVE_FORMAT_DIGIFIX        (0x0016)
+#define GST_RIFF_WAVE_FORMAT_DIALOGIC_OKI_ADPCM (0x0017)
+#define GST_RIFF_WAVE_FORMAT_MEDIAVISION_ADPCM  (0x0018)
+#define GST_RIFF_WAVE_FORMAT_CU_CODEC       (0x0019)
 #define GST_RIFF_WAVE_FORMAT_YAMAHA_ADPCM   (0x0020)
+#define GST_RIFF_WAVE_FORMAT_SONARC         (0x0021)
 #define GST_RIFF_WAVE_FORMAT_DSP_TRUESPEECH (0x0022)
+#define GST_RIFF_WAVE_FORMAT_ECHOSC1        (0x0023)
+#define GST_RIFF_WAVE_FORMAT_AUDIOFILE_AF36 (0x0024)
+#define GST_RIFF_WAVE_FORMAT_APTX           (0x0025)
+#define GST_RIFF_WAVE_FORMAT_AUDIOFILE_AF10 (0x0026)
+#define GST_RIFF_WAVE_FORMAT_PROSODY_1612   (0x0027)
+#define GST_RIFF_WAVE_FORMAT_LRC            (0x0028)
+#define GST_RIFF_WAVE_FORMAT_DOLBY_AC2      (0x0030)
 #define GST_RIFF_WAVE_FORMAT_GSM610         (0x0031)
 #define GST_RIFF_WAVE_FORMAT_MSN            (0x0032)
+#define GST_RIFF_WAVE_FORMAT_ANTEX_ADPCME   (0x0033 
+#define GST_RIFF_WAVE_FORMAT_CONTROL_RES_VQLPC (0x0034)
+#define GST_RIFF_WAVE_FORMAT_DIGIREAL       (0x0035)
+#define GST_RIFF_WAVE_FORMAT_DIGIADPCM      (0x0036)
+#define GST_RIFF_WAVE_FORMAT_CONTROL_RES_CR10  (0x0037)
+#define GST_RIFF_WAVE_FORMAT_NMS_VBXADPCM   (0x0038)
+#define GST_RIFF_WAVE_FORMAT_CS_IMAADPCM    (0x0039)
+#define GST_RIFF_WAVE_FORMAT_ECHOSC3        (0x003A)
+#define GST_RIFF_WAVE_FORMAT_ROCKWELL_ADPCM (0x003B)
+#define GST_RIFF_WAVE_FORMAT_ROCKWELL_DIGITALK (0x003C)
+#define GST_RIFF_WAVE_FORMAT_XEBEC          (0x003D)
 #define GST_RIFF_WAVE_FORMAT_ITU_G721_ADPCM (0x0040)
+#define GST_RIFF_WAVE_FORMAT_G728_CELP      (0x0041)
+#define GST_RIFF_WAVE_FORMAT_MSG723         (0x0042)
 #define GST_RIFF_WAVE_FORMAT_MPEGL12        (0x0050)
+#define GST_RIFF_WAVE_FORMAT_RT24           (0x0052)
+#define GST_RIFF_WAVE_FORMAT_PAC            (0x0053)
 #define GST_RIFF_WAVE_FORMAT_MPEGL3         (0x0055)
+#define GST_RIFF_WAVE_FORMAT_AMR_NB         (0x0057)
+#define GST_RIFF_WAVE_FORMAT_AMR_WB         (0x0058)
+#define GST_RIFF_WAVE_FORMAT_LUCENT_G723    (0x0059)
+#define GST_RIFF_WAVE_FORMAT_CIRRUS         (0x0060)
+#define GST_RIFF_WAVE_FORMAT_ADPCM_IMA_DK4  (0x0061)  /* not official */
+#define GST_RIFF_WAVE_FORMAT_ADPCM_IMA_DK3  (0x0062)  /* not official */
+/* FIXME: where are these from? are they used at all? */
+#if 0
+#define GST_RIFF_WAVE_FORMAT_ESPCM          (0x0061)
 #define GST_RIFF_WAVE_FORMAT_VOXWARE        (0x0062)
+#endif
+#define GST_RIFF_WAVE_FORMAT_CANOPUS_ATRAC  (0x0063)
+#define GST_RIFF_WAVE_FORMAT_G726_ADPCM     (0x0064)
+#define GST_RIFF_WAVE_FORMAT_G722_ADPCM     (0x0065)
+#define GST_RIFF_WAVE_FORMAT_DSAT_DISPLAY   (0x0067)
+#define GST_RIFF_WAVE_FORMAT_ADPCM_IMA_WAV (0x0069)
+/* FIXME: where are these from? are they used at all? */
+#if 0
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_BYTE_ALIGNED (0x0069)
+#endif
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_AC8    (0x0070)
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_AC10   (0x0071)
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_AC16   (0x0072)
@@ -304,26 +358,87 @@ typedef struct _gst_riff_strf_auds {       /* == WaveHeader (?) */
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_VR12   (0x0077)
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_VR18   (0x0078)
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_TQ40   (0x0079)
+#define GST_RIFF_WAVE_FORMAT_SOFTSOUND      (0x0080)
 #define GST_RIFF_WAVE_FORMAT_VOXWARE_TQ60   (0x0081)
+#define GST_RIFF_WAVE_FORMAT_MSRT24         (0x0082)
+#define GST_RIFF_WAVE_FORMAT_G729A          (0x0083)
+#define GST_RIFF_WAVE_FORMAT_MVI_MVI2       (0x0084)
+#define GST_RIFF_WAVE_FORMAT_DF_G726        (0x0085)
+#define GST_RIFF_WAVE_FORMAT_DF_GSM610      (0x0086)
+#define GST_RIFF_WAVE_FORMAT_ISIAUDIO       (0x0088)
+#define GST_RIFF_WAVE_FORMAT_ONLIVE         (0x0089)
+#define GST_RIFF_WAVE_FORMAT_SBC24          (0x0091)
+#define GST_RIFF_WAVE_FORMAT_DOLBY_AC3_SPDIF  (0x0092)
+#define GST_RIFF_WAVE_FORMAT_MEDIASONIC_G723  (0x0093)
+#define GST_RIFF_WAVE_FORMAT_PROSODY_8KBPS  (0x0094)
+#define GST_RIFF_WAVE_FORMAT_ZYXEL_ADPCM    (0x0097)
+#define GST_RIFF_WAVE_FORMAT_PHILIPS_LPCBB  (0x0098)
+#define GST_RIFF_WAVE_FORMAT_PACKED         (0x0099)
+#define GST_RIFF_WAVE_FORMAT_MALDEN_PHONYTALK (0x00A0)
 #define GST_RIFF_WAVE_FORMAT_AAC            (0x00ff)
+#define GST_RIFF_WAVE_FORMAT_RHETOREX_ADPCM (0x0100)
 #define GST_RIFF_IBM_FORMAT_MULAW           (0x0101)
 #define GST_RIFF_IBM_FORMAT_ALAW            (0x0102)
 #define GST_RIFF_IBM_FORMAT_ADPCM           (0x0103)
+#define GST_RIFF_WAVE_FORMAT_VIVO_G723      (0x0111)
+#define GST_RIFF_WAVE_FORMAT_VIVO_SIREN     (0x0112)
+#define GST_RIFF_WAVE_FORMAT_DIGITAL_G723   (0x0123)
+#define GST_RIFF_WAVE_FORMAT_SANYO_LD_ADPCM (0x0125)
+#define GST_RIFF_WAVE_FORMAT_SIPROLAB_ACEPLNET  (0x0130)
+#define GST_RIFF_WAVE_FORMAT_SIPROLAB_ACELP4800 (0x0131)
+#define GST_RIFF_WAVE_FORMAT_SIPROLAB_ACELP8V3  (0x0132)
+#define GST_RIFF_WAVE_FORMAT_SIPROLAB_G729   (0x0133)
+#define GST_RIFF_WAVE_FORMAT_SIPROLAB_G729A  (0x0134)
+#define GST_RIFF_WAVE_FORMAT_SIPROLAB_KELVIN (0x0135)
+#define GST_RIFF_WAVE_FORMAT_G726ADPCM       (0x0140)
+#define GST_RIFF_WAVE_FORMAT_QUALCOMM_PUREVOICE (0x0150)
+#define GST_RIFF_WAVE_FORMAT_QUALCOMM_HALFRATE  (0x0151)
+#define GST_RIFF_WAVE_FORMAT_TUBGSM             (0x0155)
 #define GST_RIFF_WAVE_FORMAT_WMAV1          (0x0160)
 #define GST_RIFF_WAVE_FORMAT_WMAV2          (0x0161)
 #define GST_RIFF_WAVE_FORMAT_WMAV3          (0x0162)
 #define GST_RIFF_WAVE_FORMAT_WMAV3_L        (0x0163)
+#define GST_RIFF_WAVE_FORMAT_CREATIVE_ADPCM (0x0200)
+#define GST_RIFF_WAVE_FORMAT_CREATIVE_FASTSPEECH8  (0x0202)
+#define GST_RIFF_WAVE_FORMAT_CREATIVE_FASTSPEECH10 (0x0203)
+#define GST_RIFF_WAVE_FORMAT_UHER_ADPCM     (0x0210)
+#define GST_RIFF_WAVE_FORMAT_QUARTERDECK    (0x0220)
+#define GST_RIFF_WAVE_FORMAT_ILINK_VC       (0x0230)
+#define GST_RIFF_WAVE_FORMAT_RAW_SPORT      (0x0240)
+#define GST_RIFF_WAVE_FORMAT_IPI_HSX        (0x0250)
+#define GST_RIFF_WAVE_FORMAT_IPI_RPELP      (0x0251)
+#define GST_RIFF_WAVE_FORMAT_CS2            (0x0260)
 #define GST_RIFF_WAVE_FORMAT_SONY_ATRAC3    (0x0270)
+#define GST_RIFF_WAVE_FORMAT_SIREN          (0x028E)
+#define GST_RIFF_WAVE_FORMAT_FM_TOWNS_SND   (0x0300)
+#define GST_RIFF_WAVE_FORMAT_BTV_DIGITAL    (0x0400)
+#define GST_RIFF_WAVE_FORMAT_IMC            (0x0401)
+#define GST_RIFF_WAVE_FORMAT_QDESIGN_MUSIC  (0x0450)
+#define GST_RIFF_WAVE_FORMAT_VME_VMPCM      (0x0680)
+#define GST_RIFF_WAVE_FORMAT_TPC            (0x0681)
+#define GST_RIFF_WAVE_FORMAT_OLIGSM         (0x1000)
+#define GST_RIFF_WAVE_FORMAT_OLIADPCM       (0x1001)
+#define GST_RIFF_WAVE_FORMAT_OLICELP        (0x1002)
+#define GST_RIFF_WAVE_FORMAT_OLISBC         (0x1003)
+#define GST_RIFF_WAVE_FORMAT_OLIOPR         (0x1004)
+#define GST_RIFF_WAVE_FORMAT_LH_CODEC       (0x1100)
+#define GST_RIFF_WAVE_FORMAT_NORRIS         (0x1400)
+#define GST_RIFF_WAVE_FORMAT_SOUNDSPACE_MUSICOMPRESS (0x1500)
 #define GST_RIFF_WAVE_FORMAT_A52            (0x2000)
 #define GST_RIFF_WAVE_FORMAT_DTS            (0x2001)
+#define GST_RIFF_WAVE_FORMAT_SONIC          (0x2048)
+#define GST_RIFF_WAVE_FORMAT_SONIC_LS       (0x2048)
+#define GST_RIFF_WAVE_FORMAT_AAC_AC         (0x4143)
 #define GST_RIFF_WAVE_FORMAT_VORBIS1        (0x674f)
 #define GST_RIFF_WAVE_FORMAT_VORBIS2        (0x6750)
 #define GST_RIFF_WAVE_FORMAT_VORBIS3        (0x6751)
 #define GST_RIFF_WAVE_FORMAT_VORBIS1PLUS    (0x676f)
 #define GST_RIFF_WAVE_FORMAT_VORBIS2PLUS    (0x6770)
 #define GST_RIFF_WAVE_FORMAT_VORBIS3PLUS    (0x6771)
+#define GST_RIFF_WAVE_FORMAT_AAC_pm         (0x706d)
 #define GST_RIFF_WAVE_FORMAT_GSM_AMR_CBR    (0x7A21)
 #define GST_RIFF_WAVE_FORMAT_GSM_AMR_VBR    (0x7A22)
+#define GST_RIFF_WAVE_FORMAT_FLAC           (0xF1AC)
 #define GST_RIFF_WAVE_FORMAT_EXTENSIBLE     (0xFFFE)
   guint16 channels;
   guint32 rate;
@@ -358,6 +473,41 @@ typedef struct _gst_riff_dmlh {
   guint32 totalframes;
 } gst_riff_dmlh;
 
+/* taken from libsndfile/wav.c (LGPL) */
+typedef struct _gst_riff_acid {
+  /* 4 bytes (int)     type of file:
+   *  this appears to be a bit mask,however some combinations
+   *  are probably impossible and/or qualified as "errors"
+   *
+   *  0x01 On: One Shot         Off: Loop
+   *  0x02 On: Root note is Set Off: No root
+   *  0x04 On: Stretch is On,   Off: Strech is OFF
+   *  0x08 On: Disk Based       Off: Ram based
+   *  0x10 On: ??????????       Off: ????????? (Acidizer puts that ON)
+   */
+  guint32 loop_type;
+  /* 2 bytes (short)      root note
+   *  if type 0x10 is OFF : [C,C#,(...),B] -> [0x30 to 0x3B]
+   *  if type 0x10 is ON  : [C,C#,(...),B] -> [0x3C to 0x47]
+   *  (both types fit on same MIDI pitch albeit different octaves, so who cares)
+   */
+  guint16 root_note;
+  /* 2 bytes (short)      ??? always set to 0x8000
+   * 4 bytes (float)      ??? seems to be always 0
+   */
+  guint16 unknown1;
+  gfloat unknown2;
+  /* 4 bytes (int)        number of beats
+   * 2 bytes (short)      meter denominator   //always 4 in SF/ACID
+   * 2 bytes (short)      meter numerator     //always 4 in SF/ACID
+   *                      //are we sure about the order?? usually its num/denom
+   * 4 bytes (float)      tempo
+   */
+  guint32 number_of_beats;
+  guint16 meter_d, meter_n;
+  gfloat tempo;
+} gst_riff_acid;
+
 G_END_DECLS
 
 #endif /* __GST_RIFF_IDS_H__ */
